@@ -60,16 +60,23 @@ heatclient = _try_import('heatclient.client')
 ironic_inspector_client = _try_import('ironic_inspector_client.v1')
 ironicclient = _try_import('ironicclient.v1.client')
 keystoneclient = _try_import('keystoneclient.v3.client')
+manila = _try_import('manilaclient')
+manilaclient = _try_import('manilaclient.client')
+manila_api_versions = _try_import('manilaclient.api_versions')
 magnumclient = _try_import('magnumclient.v1.client')
 mistralclient = _try_import('mistralclient.api.v2.client')
 muranoclient = _try_import('muranoclient.v1.client')
 neutronclient = _try_import('neutronclient.v2_0.client')
 novaclient = _try_import('novaclient.client')
+qinlingclient = _try_import('qinlingclient.v1.client')
 senlinclient = _try_import('senlinclient.v1.client')
 swift_client = _try_import('swiftclient.client')
+swiftservice = _try_import('swiftclient.service')
 tackerclient = _try_import('tackerclient.v1_0.client')
 troveclient = _try_import('troveclient.v1.client')
+vitrageclient = _try_import('vitrageclient.v1.client')
 zaqarclient = _try_import('zaqarclient.queues.client')
+zunclient = _try_import('zunclient.v1.client')
 
 
 class NovaAction(base.OpenStackAction):
@@ -401,6 +408,35 @@ class SwiftAction(base.OpenStackAction):
         )
 
 
+class SwiftServiceAction(base.OpenStackAction):
+    _service_name = 'swift'
+
+    @classmethod
+    def _get_client_class(cls):
+        return swiftservice.SwiftService
+
+    def _create_client(self, context):
+
+        LOG.debug("Swift action security context: %s", context)
+
+        swift_endpoint = self.get_service_endpoint()
+
+        swift_opts = {
+            'os_storage_url': swift_endpoint.url % {
+                'tenant_id': context.project_id
+            },
+            'os_auth_token': context.auth_token,
+            'os_region_name': swift_endpoint.region,
+            'os_project_id': context.security.project_id,
+        }
+
+        return swiftservice.SwiftService(options=swift_opts)
+
+    @classmethod
+    def _get_client_method(cls, client):
+        return getattr(client, cls.client_method_name)
+
+
 class ZaqarAction(base.OpenStackAction):
     _service_type = 'messaging'
 
@@ -548,13 +584,13 @@ class BarbicanAction(base.OpenStackAction):
         LOG.debug("Barbican action security context: %s", context)
 
         barbican_endpoint = keystone_utils.get_endpoint_for_project('barbican')
-        keystone_endpoint = keystone_utils.get_keystone_endpoint_v2()
+        keystone_endpoint = keystone_utils.get_keystone_endpoint()
 
-        auth = identity.v2.Token(
+        auth = identity.v3.Token(
             auth_url=keystone_endpoint.url,
-            tenant_name=context.user_name,
+            project_name=context.user_name,
             token=context.auth_token,
-            tenant_id=context.project_id
+            project_id=context.project_id
         )
 
         return self._get_client_class()(
@@ -689,7 +725,7 @@ class MagnumAction(base.OpenStackAction):
 
         LOG.debug("Magnum action security context: %s", context)
 
-        keystone_endpoint = keystone_utils.get_keystone_endpoint_v2()
+        keystone_endpoint = keystone_utils.get_keystone_endpoint()
         auth_url = keystone_endpoint.url
         magnum_url = keystone_utils.get_endpoint_for_project('magnum').url
 
@@ -718,7 +754,7 @@ class MuranoAction(base.OpenStackAction):
 
         LOG.debug("Murano action security context: %s", context)
 
-        keystone_endpoint = keystone_utils.get_keystone_endpoint_v2()
+        keystone_endpoint = keystone_utils.get_keystone_endpoint()
         murano_endpoint = self.get_service_endpoint()
 
         return self._get_client_class()(
@@ -746,7 +782,7 @@ class TackerAction(base.OpenStackAction):
 
         LOG.debug("Tacker action security context: %s", context)
 
-        keystone_endpoint = keystone_utils.get_keystone_endpoint_v2()
+        keystone_endpoint = keystone_utils.get_keystone_endpoint()
         tacker_endpoint = self.get_service_endpoint()
 
         return self._get_client_class()(
@@ -774,7 +810,7 @@ class SenlinAction(base.OpenStackAction):
 
         LOG.debug("Senlin action security context: %s", context)
 
-        keystone_endpoint = keystone_utils.get_keystone_endpoint_v2()
+        keystone_endpoint = keystone_utils.get_keystone_endpoint()
         senlin_endpoint = self.get_service_endpoint()
 
         return self._get_client_class()(
@@ -788,7 +824,8 @@ class SenlinAction(base.OpenStackAction):
 
     @classmethod
     def _get_fake_client(cls):
-        return cls._get_client_class()("http://127.0.0.1:8778")
+        sess = keystone_utils.get_admin_session()
+        return cls._get_client_class()(authenticator=sess.auth)
 
 
 class AodhAction(base.OpenStackAction):
@@ -878,3 +915,131 @@ class GlareAction(base.OpenStackAction):
     @classmethod
     def _get_fake_client(cls):
         return cls._get_client_class()("http://127.0.0.1:9494/")
+
+
+class VitrageAction(base.OpenStackAction):
+    _service_type = 'rca'
+
+    @classmethod
+    def _get_client_class(cls):
+        return vitrageclient.Client
+
+    def _create_client(self, context):
+
+        LOG.debug("Vitrage action security context: %s", context)
+
+        vitrage_endpoint = self.get_service_endpoint()
+
+        endpoint_url = keystone_utils.format_url(
+            vitrage_endpoint.url,
+            {'tenant_id': context.project_id}
+        )
+
+        session_and_auth = self.get_session_and_auth(context)
+
+        return vitrageclient.Client(
+            session=session_and_auth['session'],
+            endpoint_override=endpoint_url
+        )
+
+    @classmethod
+    def _get_fake_client(cls):
+        return cls._get_client_class()()
+
+
+class ZunAction(base.OpenStackAction):
+    _service_name = 'appcontainer'
+
+    @classmethod
+    def _get_client_class(cls):
+        return zunclient.Client
+
+    def _create_client(self, context):
+
+        LOG.debug("Zun action security context: %s", context)
+
+        keystone_endpoint = keystone_utils.get_keystone_endpoint()
+        zun_endpoint = self.get_service_endpoint()
+        session_and_auth = self.get_session_and_auth(context)
+
+        client = self._get_client_class()(
+            '1',
+            endpoint_override=zun_endpoint.url,
+            auth_url=keystone_endpoint.url,
+            session=session_and_auth['session']
+        )
+
+        return client
+
+    @classmethod
+    def _get_fake_client(cls):
+        session = keystone_utils.get_admin_session()
+        return cls._get_client_class()(
+            endpoint_override="http://127.0.0.1:9517/",
+            session=session
+        )
+
+
+class QinlingAction(base.OpenStackAction):
+    _service_type = 'function-engine'
+
+    @classmethod
+    def _get_client_class(cls):
+        return qinlingclient.Client
+
+    def _create_client(self, context):
+        qinling_endpoint = self.get_service_endpoint()
+        session_and_auth = self.get_session_and_auth(context)
+
+        return self._get_client_class()(endpoint_override=qinling_endpoint.url,
+                                        session=session_and_auth['session'])
+
+    @classmethod
+    def _get_fake_client(cls):
+        session = keystone_utils.get_admin_session()
+        return cls._get_client_class()(
+            endpoint_override="http://127.0.0.1:7070/",
+            session=session
+        )
+
+
+class ManilaAction(base.OpenStackAction):
+    _service_type = 'sharev2'
+
+    @classmethod
+    def _get_client_class(cls):
+        return manilaclient.Client
+
+    def _create_client(self, context):
+
+        LOG.debug("Manila action security context: %s", context)
+
+        manila_endpoint = self.get_service_endpoint()
+
+        session_and_auth = self.get_session_and_auth(context)
+
+        temp_client = self._get_client_class()(
+            manila.API_MAX_VERSION,
+            service_catalog_url=manila_endpoint.url,
+            session=session_and_auth['auth']
+        )
+
+        discovered_version = manila_api_versions.discover_version(
+            temp_client,
+            manila.API_MAX_VERSION
+        )
+
+        client = self._get_client_class()(
+            discovered_version,
+            service_catalog_url=manila_endpoint.url,
+            session=session_and_auth['session']
+        )
+
+        return client
+
+    @classmethod
+    def _get_fake_client(cls):
+        return cls._get_client_class()(
+            manila.API_MAX_VERSION,
+            input_auth_token='token',
+            service_catalog_url='http://127.0.0.1:8786')
