@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2013 - Mirantis, Inc.
+# Copyright 2015 - StackStorm, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -20,8 +19,12 @@ import wsmeext.pecan as wsme_pecan
 
 from mistral.api.controllers import resource
 from mistral.api.controllers.v2 import action
+from mistral.api.controllers.v2 import action_execution
 from mistral.api.controllers.v2 import cron_trigger
+from mistral.api.controllers.v2 import environment
+from mistral.api.controllers.v2 import event_trigger
 from mistral.api.controllers.v2 import execution
+from mistral.api.controllers.v2 import service
 from mistral.api.controllers.v2 import task
 from mistral.api.controllers.v2 import workbook
 from mistral.api.controllers.v2 import workflow
@@ -49,6 +52,10 @@ class Controller(object):
     executions = execution.ExecutionsController()
     tasks = task.TasksController()
     cron_triggers = cron_trigger.CronTriggersController()
+    environments = environment.EnvironmentController()
+    action_executions = action_execution.ActionExecutionsController()
+    services = service.ServicesController()
+    event_triggers = event_trigger.EventTriggersController()
 
     @wsme_pecan.wsexpose(RootResource)
     def index(self):
